<!--报警数据分析统计-->
<template>
  <div class="alarm-data-statistics">
    <public-title title="物资消耗分析-部门物资统计" />
    <div class="chart-container">
      <div class="search-box">
        <div class="search-item">
          <div class="search-title">部门</div>
          <el-cascader ref="orgCascader" :options="orgOptions" v-model="orgValue"
            :props="{ checkStrictly: true, value: 'id', label: 'name' }" clearable :show-all-levels="false"
            @change="orgChange"></el-cascader>
        </div>
        <div class="search-item">
          <div class="search-title" style="margin-top: 20px;">物资分类</div>
          <el-cascader ref="classifyCascader" :options="classifyOptions" v-model="classifyValue"
            :props="{ checkStrictly: true, value: 'id', label: 'name' }" clearable :show-all-levels="false"
            @change="classifyChange"></el-cascader>
        </div>
      </div>
      <div id="departmental-material" style="width: 100%;height: 100%;" />
    </div>
    <detailsDialog ref="detailsDialog"></detailsDialog>
  </div>
</template>

<script>
import * as echarts from 'echarts'
import api from '../api'
import PublicTitle from '../PublicTitle/index.vue'
import detailsDialog from '../detailsDialog/index.vue'

export default {
  name: 'departmentalMaterial',
  components: { PublicTitle, detailsDialog },
  props: {
    searchDate: {
      type: Object,
      default: () => { }
    }
  },
  watch: {
    searchDate: {
      handler(newVal, oldVal) {
        this.getChartData()
      },
      deep: true
    }
  },
  data() {
    return {
      myChart: null,  // 图表实例对象
      chartData: [],
      orgOptions: [],
      orgValue: '417700605146974917',
      classifyOptions: [],
      classifyValue: '1573859859592515584',
      requestData: {
        parentId: '0',
        deptId: '417700605146974917',
        startDate: '',
        endDate: ''
      }
    }
  },
  created() {
    this.getClassifyOptions()
    this.getOrgData()
    this.getChartData()
  },
  mounted() {
    this.myChart = echarts.init(document.getElementById('departmental-material'))
  },
  methods: {
    async getChartData() {
      let data = { ...this.requestData, ...this.searchDate }
      api.getDepartmentalMaterial(data, res => {
        if (res.state) {
          this.chartData = res.value.find(item => item.classId === this.classifyValue)
          this.chartData.total = (this.chartData.cgNum || 0) + (this.chartData.ckNum || 0)

        } else {
          this.chartData = {}
        }
        this.$nextTick(_ => this.initEcharts())
      })
    },
    // 部门查询
    getOrgData() {
      api.getOrgData(res => {
        this.orgOptions = this.getTreeData(res[0]?.children || [])
      })
    },
    // 物资分类查询
    getClassifyOptions() {
      api.loadAllClass(res => {
        this.classifyOptions = res.value
      })
    },
    getTreeData(data) {
      for (var i = 0; i < data.length; i++) {
        if (!data[i].children.length) {
          data[i].children = undefined;
        } else {
          this.getTreeData(data[i].children);
        }
      }
      return data;
    },
    classifyChange() {
      let { data } = this.$refs.classifyCascader?.getCheckedNodes()[0]
      if (data) {
        this.classifyValue = data.id
        this.requestData.parentId = data.parentId
        this.getChartData()
      }
    },
    orgChange() {
      let { data } = this.$refs.orgCascader?.getCheckedNodes()[0]
      if (data) {
        this.orgValue = data.id
        this.requestData.deptId = data.parentId
        this.getChartData()
      }
    },
    // 初始化图表
    initEcharts() {
      this.myChart.off('click')
      this.myChart.setOption({
        color: ['#67C23A', '#ff6e79', '#ffda68',],
        tooltip: {
          trigger: 'item',
          textStyle: {
            fontSize: 14,
            color: '#606266'
          }
        },
        graphic: [{
          type: 'group',
          left: '50%',
          top: '57%',
          bounding: 'raw',
          children: [{
            type: 'text',
            style: {
              text: `总计\n${this.chartData?.total || 0}`,
              fontSize: 17,
              lineHeight: 28,
              fill: '#36d9c6',
              textVerticalAlign: 'middle',
              textAlign: 'center'
            }
          }]
        }],
        legend: {
          position: 'center',
          top: 0,
          textStyle: {
            fontSize: 14,
            color: '#606266'
          }
        },
        series: [
          {
            name: '整体成本分析',
            type: 'pie',
            clockwise: false,
            startAngle: 90,
            radius: ['50%', '80%'],
            center: ['50%', '57%'],
            avoidLabelOverlap: false,
            itemStyle: {
              borderColor: 'rgba(255,255,255,0)',
              borderWidth: 3
            },
            data: [
              {
                value: this.chartData?.cgNum || 0,
                name: '采购数量'
              },

              {
                value: this.chartData?.ckNum || 0,
                name: '领用数量'
              },
              // {
              //   value: this.chartData?.kcNum || 0,
              //   name: '库存数量'
              // },
            ],
            label: {
              normal: {
                show: true,
                position: 'outside',
                formatter: ({ percent, name, value }) => {
                  return name + '\n' + value + '\n'
                },
                textStyle: {
                  align: 'center',
                  fontSize: 14,
                  lineHeight: 18,
                  color: '#606266'
                }
              }
            }
          },
          {
            name: '整体成本分析',
            type: 'pie',
            clockwise: false,
            startAngle: 90,
            radius: ['50%', '80%'],
            center: ['50%', '57%'],
            avoidLabelOverlap: false,
            showEmptyCircle: true,
            itemStyle: {
              // borderRadius: 10,
              borderColor: 'rgba(255,255,255,0)',
              borderWidth: 3
            },
            data: [
              {
                value: this.chartData?.cgNum || 0,
                name: '采购数量'
              },

              {
                value: this.chartData?.ckNum || 0,
                name: '领用数量'
              },
              // {
              //   value: this.chartData?.kcNum || 0,
              //   name: '库存数量'
              // },
            ],
            label: {
              normal: {
                show: true,
                position: 'inside',
                formatter: ({ percent, name, value }) => (percent ? percent.toFixed(0) + '%' : ''),
                textStyle: {
                  align: 'center',
                  fontSize: 14,
                  fontWeight: 'bolder',
                  color: '#fff'
                }
              }
            }
          }
        ]
      })
      this.myChart.on('click', e => {
        const data = { ...this.requestData, ...this.searchDate }
        data.parentId = this.classifyValue
        this.$refs.detailsDialog.open(data)
      })
      //随着屏幕大小调节图表
      window.addEventListener('resize', _ => this.myChart.resize())
    }
  },
  beforeDestroy() {
    // 取消事件的监听
    window.removeEventListener('resize', _ => this.myChart.resize())
  }
}
</script>

<style lang="scss" scoped>
.alarm-data-statistics {
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;

  .chart-container {
    flex: 1;
    display: flex;
    // align-items: center;
    width: 100%;
    box-sizing: border-box;
    padding: 15px 20px;

    .search-box {
      width: 50%;
      height: fit-content;

      .search-item {
        .search-title {
          padding: 5px 0;
        }
      }

    }
  }
}
</style>